@@ -56,7 +56,7 @@ static void gfm_version(void)
 	printf(_("GFM - Version %s, (C) 2006-2007 Tyler Cassidy & Romain Lievin\n"), GFM_VERSION);
 	printf(_("THIS PROGRAM COMES WITH ABSOLUTELY NO WARRANTY\n"));
 	printf(_("PLEASE READ THE DOCUMENTATION FOR DETAILS\n"));
-	printf(_("built on %s %s\n"), __DATE__, __TIME__);
+	//printf(_("built on %s %s\n"), __DATE__, __TIME__);
 	fflush(stdout);
 }
 
